aboutsummaryrefslogtreecommitdiff
path: root/src/connection/chroot.lisp
diff options
context:
space:
mode:
Diffstat (limited to 'src/connection/chroot.lisp')
-rw-r--r--src/connection/chroot.lisp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/connection/chroot.lisp b/src/connection/chroot.lisp
index b681e48..e40d7ca 100644
--- a/src/connection/chroot.lisp
+++ b/src/connection/chroot.lisp
@@ -109,10 +109,10 @@ should be the mount point, without the chroot's root prefixed.")
;; ensure they don't get bogus values when this connection object is used
;; in UPLOAD-ALL-PREREQUISITE-DATA.
(connection-connattr connection :remote-home)
;; Obtain & cache XDG_CACHE_HOME inside the chroot, and compute DATADIR.
(let ((xdg-cache-home (connection-connattr connection :XDG_CACHE_HOME)))
(setf connection (change-class connection 'chroot.fork-connection)
- (slot-value connection 'datadir)
+ (slot-value connection 'rehome-datadir)
(merge-pathnames
"consfigurator/data/" (chroot-pathname xdg-cache-home into))))
(continue-connection connection remaining)))
@@ -109,10 +109,10 @@ should be the mount point, without the chroot's root prefixed.")
;; in UPLOAD-ALL-PREREQUISITE-DATA.
(connection-connattr connection :remote-home)
- ;; Obtain & cache XDG_CACHE_HOME inside the chroot, and compute DATADIR.
+ ;; Cache XDG_CACHE_HOME inside the chroot, and compute REHOME-DATADIR.
(let ((xdg-cache-home (connection-connattr connection :XDG_CACHE_HOME)))
(setf connection (change-class connection 'chroot.fork-connection)